# Bruin CLI

A toolbox for UCLA students in various events
Project published on PyPi: https://pypi.org/project/bruin/

## Installation:
```sh
pip install bruin
```

## Simple Usages:

### Meal
Print today's dining menu

```sh
bruin meal
```
Print hour of operations:
```sh
bruin meal --hour=['', 'all', 'De Neve', etc.]
```

Print detail menu:
```sh
bruin meal --detail=['Breakfast', 'Lunch', 'Dinner']
```